@@ -7,13 +7,17 @@ use warnings 'all';
 ###############################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 ###############################################################################
 # MOOSE
 use Moose 0.89;
 use MooseX::StrictConstructor 0.08;
 
+###############################################################################
+# MOOSE TYPES
+use Net::NSCA::Client::Library qw(InitializationVector);
+
 ###############################################################################
 # MODULES
 use Convert::Binary::C 0.74;
@@ -29,19 +33,23 @@ use namespace::clean 0.04 -except => [qw(meta)];
 __PACKAGE__->meta->add_package_symbol(q{&()}  => sub {                  });
 __PACKAGE__->meta->add_package_symbol(q{&(""} => sub { shift->to_string });
 
+###############################################################################
+# CONSTANTS
+Readonly our $INITIALIZATION_VECTOR_LENGTH => 128;
+
 ###############################################################################
 # PRIVATE CONSTANTS
-Readonly my $BYTES_FOR_16BITS    => 2;
-Readonly my $BYTES_FOR_32BITS    => 4;
-Readonly my $TRANSMITTED_IV_SIZE => 128;
+Readonly my $BYTES_FOR_16BITS => 2;
+Readonly my $BYTES_FOR_32BITS => 4;
 
 ###############################################################################
 # ATTRIBUTES
 has initialization_vector => (
 	is  => 'ro',
-	isa => 'Str',
+	isa => InitializationVector,
 
 	builder => '_build_initialization_vector',
+	coerce  => 1,
 );
 has unix_timestamp => (
 	is  => 'ro',
@@ -92,8 +100,8 @@ sub to_string {
 sub _build_initialization_vector {
 	my ($self) = @_;
 
-	return Crypt::Random::makerandom(
-		Size     => $TRANSMITTED_IV_SIZE,
+	return Crypt::Random::makerandom_octet(
+		Length   => $INITIALIZATION_VECTOR_LENGTH,
 		Strength => 1,
 	);
 }
@@ -122,7 +130,7 @@ sub _init_packet_struct {
 	# Add the init_packet_struct structure
 	$c->parse(<<"ENDC");
 		struct init_packet_struct {
-			char      iv[$TRANSMITTED_IV_SIZE];
+			char      iv[$INITIALIZATION_VECTOR_LENGTH];
 			u_int32_t timestamp;
 		};
 ENDC
@@ -170,6 +178,10 @@ sub _setup_c_object {
 	return $c;
 }
 
+###############################################################################
+# MAKE MOOSE OBJECT IMMUTABLE
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -181,7 +193,7 @@ protocol
 
 =head1 VERSION
 
-This documentation refers to L<Net::NSCA::Client::InitialPacket> version 0.001
+This documentation refers to L<Net::NSCA::Client::InitialPacket> version 0.002
 
 =head1 SYNOPSIS
 
@@ -238,9 +250,9 @@ C<$packet_string> is a string of the data packet in the network form.
 =head2 initialization_vector
 
 This is a binary string, which is the exact length of the constant
-L</$TRANSMITTED_IV_SIZE>. If a string less than this length is provided,
-then it is automatically padded with NULLs. If not specified, this will
-default to random bytes generated by a L<Crypt::Random>.
+L</$INITIALIZATION_VECTOR_LENGTH>. If a string less than this length is
+provided, then it is automatically padded with NULLs. If not specified, this
+will default to random bytes generated by a L<Crypt::Random>.
 
 =head2 unix_timestamp
 
@@ -259,7 +271,7 @@ string representation is what will be sent over the network.
 
 Constants provided by this library are protected by the L<Readonly> module.
 
-=head2 C<$TRANSMITTED_IV_SIZE>
+=head2 C<$INITIALIZATION_VECTOR_LENGTH>
 
 This is the length of the L</initialization_vector>.
 
